// Satyr 08/05/2018 11:51
// Plantilla para conjuntos
inherit "/obj/conjunto_nuevo.c";

// Prototipo de una función personalizada que usaremos más adelante
int poner_levitar(object quien, object item, int piezas, int signo);

void setup()
{
    // El nombre que se mostrará en la armería. Se pueden usar colores
    set_short("Ejemplo de conjunto");

    // Para que los mensajes salgan bien es necesario establecer el género
    fijar_genero(1);

    // La base ya hace un generar_alias_y_plurales(), pero si vuestro
    // conjunto no tiene "conjunto" en el short es recomendable tener
    // esto para que sean fáciles de ver
    add_alias("conjunto");

    /**
     * Si descomentamos esto el conjunto se convertirá en parcial: es decir,
     * dará bono a medida que nos equipemos piezas. El comportamiento por
     * defecto es solo tener bonos si nos equipamos todas.
     **/
    // fijar_conjunto_parcial();

    /**
     * Aquí hay que establecer la ruta de todos los objetos que componen
     * el conjunto
     */
    fijar_piezas(({}));

    /**
     * Esta función permite asignar un bono temporal a cualquier característica
     * (fue, des, con, daño, poder_magico, etc.) al equiparse un número de
     * piezas dado.
     *
     * @param numero_piezas  Numero de piezas a los que queremos que bonifique
     * @param carac          Característica a bonificar
     * @param valor          Cantidad de atributo a otorgar
     *
     * En este ejemplo damos +1 a des al equipar 2 piezas
     */
    nuevo_beneficio_caracteristica(2, "des", 1);

    /**
     * Esta función permite asignar un bono especial a cualqueir característica.
     *
     * El bono vendrá en forma de función, por lo que realmente podremos
     * hacer cualquier cosa con él.
     *
     * @param numero_piezas  Numero de piezas a los que queremos que bonifique
     * @param f              Función a ejecutar
     *
     * La función evaluada recibirá estos parámetros:
     *
     * @param object  Jugador que se equipa el conjunto
     * @param object  Objeto que se equipa el jugador cuando se llega al número
     *                de piezas que dispara el beneficio
     * @param int     Número de piezas que tiene el jugador equipado
     * @param int     +1 (nos estamos equipando) -1 (nos desequipamos)
     *
     * ESPECIAL ATENCIÓN al signo. La función será responsable de bonificar
     * y de ELIMINAR la bonificación. Es decir, si a 3 piezas ganamos algo,
     * cuando nos quitemos las piezas tendremos que quitar el bono.
     *
     * Se espera que la función devuelva 1.
     *
     * En nuestro ejemplo vamos a ejecutar la función "Poner_levitar"
     */
    nuevo_beneficio_funcion(3, ( : poner_levitar:));
}

/**
 * Función personalizada que usamos para nuestro beneficio
 */
int poner_levitar(object quien, object item, int piezas, int signo)
{
    if (piezas >= 3) {
        quien->add_static_property("levitar", 1);
    } else {
        quien->remove_static_property("levitar");
    }
    return 1;
}

// Si metemos un beneficio especial tendremos que mostrarlo en esta ayuda
// en el número de piezas que corresponda
string dame_ayuda_especial(int piezas, mixed beneficio)
{
    if (piezas != 2) {
        return ::dame_ayuda_especial(piezas, beneficio);
    }

    return "Este conjunto te permite levitar.";
}

// Funciones personalizables para mostrar mensajes al equipar/desequipar piezas
void mostrar_mensajes_equipar_conjunto(object pj, object item, int piezas)
{
}
void mostrar_mensajes_desequipar_conjunto(object pj, object item, int piezas)
{
}
